@@ -15,12 +15,12 @@ use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::NwFilter v0.0.1;
+package Sys::Async::Virt::NwFilter v0.0.2;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.1;
+use Protocol::Sys::Virt::Remote::XDR v0.0.2;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 
@@ -33,16 +33,16 @@ sub new {
     }, $class;
 }
 
-sub get_xml_desc($self, $flags = 0) {
-    return $self->{client}->_call(
+async sub get_xml_desc($self, $flags = 0) {
+    return (await $self->{client}->_call(
         $remote->PROC_NWFILTER_GET_XML_DESC,
-        { nwfilter => $self->{id}, flags => $flags // 0 } );
+        { nwfilter => $self->{id}, flags => $flags // 0 } ))->{xml};
 }
 
 sub undefine($self) {
-    return $self->{client}->_call(
+    return ($self->{client}->_call(
         $remote->PROC_NWFILTER_UNDEFINE,
-        { nwfilter => $self->{id},  } );
+        { nwfilter => $self->{id},  } ));
 }
 
 
@@ -57,7 +57,7 @@ Sys::Async::Virt::NwFilter - Client side proxy to remote LibVirt network filter
 
 =head1 VERSION
 
-v0.0.1
+v0.0.2
 
 =head1 SYNOPSIS
 
